"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const metadata_registry_1 = require("../metadata-registry");
const fs_1 = require("fs");
const path_1 = require("path");
const fileSystemHandler_1 = require("../utils/fileSystemHandler");
const streams_1 = require("./streams");
const constants_1 = require("../utils/constants");
const errors_1 = require("../errors");
class MetadataConverter {
    constructor(registryAccess = new metadata_registry_1.RegistryAccess()) {
        this.registryAccess = registryAccess;
    }
    /**
     * Convert metadata components to another SFDX file format.
     *
     * @param components Components to convert
     * @param targetFormat Format to convert the component files to
     * @param output Configuration for outputting the converted files
     */
    convert(components, targetFormat, output) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // TODO: evaluate if a builder pattern for manifest creation is more efficient here
                const manifestGenerator = new metadata_registry_1.ManifestGenerator(this.registryAccess);
                const manifestContents = manifestGenerator.createManifest(components);
                const packagePath = this.getPackagePath(output);
                const tasks = [];
                // initialize writer and create manifest
                let writer;
                switch (output.type) {
                    case 'directory':
                        writer = new streams_1.StandardWriter(packagePath);
                        const manifestPath = path_1.join(packagePath, constants_1.PACKAGE_XML_FILE);
                        fileSystemHandler_1.ensureDirectoryExists(packagePath);
                        tasks.push(fs_1.promises.writeFile(manifestPath, manifestContents));
                        break;
                    case 'zip':
                        writer = new streams_1.ZipWriter(packagePath);
                        writer.addToZip(manifestContents, constants_1.PACKAGE_XML_FILE);
                        break;
                }
                const conversionPipeline = streams_1.pipeline(new streams_1.ComponentReader(components), new streams_1.ComponentConverter(targetFormat), writer);
                tasks.push(conversionPipeline);
                yield Promise.all(tasks);
                const result = { packagePath };
                if (output.type === 'zip' && !packagePath) {
                    result.zipBuffer = writer.buffer;
                }
                return result;
            }
            catch (e) {
                throw new errors_1.ConversionError(e);
            }
        });
    }
    getPackagePath(outputConfig) {
        let packagePath;
        const { outputDirectory, packageName } = outputConfig;
        if (outputDirectory) {
            const name = packageName || `${constants_1.DEFAULT_PACKAGE_PREFIX}_${Date.now()}`;
            packagePath = path_1.join(outputDirectory, name);
            packagePath += outputConfig.type === 'zip' ? '.zip' : '';
        }
        return packagePath;
    }
}
exports.MetadataConverter = MetadataConverter;
//# sourceMappingURL=metadataConverter.js.map