"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const mixedContent_1 = require("./mixedContent");
const registry_1 = require("../../utils/registry");
const path_1 = require("path");
const fs_1 = require("fs");
const fileSystemHandler_1 = require("../../utils/fileSystemHandler");
const utils_1 = require("../../utils");
class Decomposed extends mixedContent_1.MixedContent {
    getMetadataXmlPath(pathToSource) {
        const componentRoot = this.getPathToContent(pathToSource);
        return registry_1.findMetadataXml(componentRoot, path_1.basename(componentRoot));
    }
    getSourcePaths() {
        return undefined;
    }
    getChildren(xmlPath) {
        return this._getChildren(path_1.dirname(xmlPath));
    }
    _getChildren(dirPath) {
        const children = [];
        for (const fileName of fs_1.readdirSync(dirPath)) {
            const currentPath = path_1.join(dirPath, fileName);
            if (this.forceIgnore.denies(currentPath)) {
                continue;
            }
            else if (fileSystemHandler_1.isDirectory(currentPath)) {
                children.push(...this._getChildren(currentPath));
            }
            else {
                const childXml = registry_1.parseMetadataXml(fileName);
                // second condition ensures we don't add the parent's metadata xml as a child
                if (childXml && childXml.suffix !== this.type.suffix) {
                    // TODO: Log warning if missing child type definition
                    const childTypeId = this.type.children.suffixes[childXml.suffix];
                    children.push({
                        fullName: utils_1.baseName(fileName),
                        type: this.type.children.types[childTypeId],
                        xml: currentPath
                    });
                }
            }
        }
        return children;
    }
}
exports.Decomposed = Decomposed;
//# sourceMappingURL=decomposed.js.map